@@ -21,6 +21,7 @@
 
 package HTML::TableParser;
 
+require 5.8.1;
 use strict;
 use warnings;
 
@@ -29,9 +30,12 @@ use HTML::Parser;
 
 use HTML::TableParser::Table;
 
+## no critic ( ProhibitAccessOfPrivateData )
+
+
 our @ISA = qw(HTML::Parser);
 
-our $VERSION = '0.36';
+our $VERSION = '0.39';
 
 # Preloaded methods go here.
 
